==> ask-smapi-model-1.8.2.tar.gz: ask-smapi-model-1.8.2/ask_smapi_model/v1/skill/interaction_model/jobs/list_job_definitions_response.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union, Any
    from datetime import datetime
    from ask_smapi_model.v1.skill.interaction_model.jobs.job_definition_metadata import JobDefinitionMetadata as Jobs_JobDefinitionMetadataV1
    from ask_smapi_model.v1.skill.interaction_model.jobs.job_api_pagination_context import JobAPIPaginationContext as Jobs_JobAPIPaginationContextV1
    from ask_smapi_model.v1.links import Links as V1_LinksV1


class ListJobDefinitionsResponse(object):
    """
    The response of list job definitions.


    :param pagination_context: 
    :type pagination_context: (optional) ask_smapi_model.v1.skill.interaction_model.jobs.job_api_pagination_context.JobAPIPaginationContext
    :param links: 
    :type links: (optional) ask_smapi_model.v1.links.Links
    :param jobs: 
    :type jobs: (optional) list[ask_smapi_model.v1.skill.interaction_model.jobs.job_definition_metadata.JobDefinitionMetadata]

    """
    deserialized_types = {
        'pagination_context': 'ask_smapi_model.v1.skill.interaction_model.jobs.job_api_pagination_context.JobAPIPaginationContext',
        'links': 'ask_smapi_model.v1.links.Links',
        'jobs': 'list[ask_smapi_model.v1.skill.interaction_model.jobs.job_definition_metadata.JobDefinitionMetadata]'
    }  # type: Dict

    attribute_map = {
        'pagination_context': 'paginationContext',
        'links': '_links',
        'jobs': 'jobs'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, pagination_context=None, links=None, jobs=None):
        # type: (Optional[Jobs_JobAPIPaginationContextV1], Optional[V1_LinksV1], Optional[List[Jobs_JobDefinitionMetadataV1]]) -> None
        """The response of list job definitions.

        :param pagination_context: 
        :type pagination_context: (optional) ask_smapi_model.v1.skill.interaction_model.jobs.job_api_pagination_context.JobAPIPaginationContext
        :param links: 
        :type links: (optional) ask_smapi_model.v1.links.Links
        :param jobs: 
        :type jobs: (optional) list[ask_smapi_model.v1.skill.interaction_model.jobs.job_definition_metadata.JobDefinitionMetadata]
        """
        self.__discriminator_value = None  # type: str

        self.pagination_context = pagination_context
        self.links = links
        self.jobs = jobs

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, ListJobDefinitionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other

==> ask-smapi-model-1.13.1.tar.gz: ask-smapi-model-1.13.1/ask_smapi_model/v1/skill/interaction_model/jobs/list_job_definitions_response.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union, Any
    from datetime import datetime
    from ask_smapi_model.v1.skill.interaction_model.jobs.job_api_pagination_context import JobAPIPaginationContext as JobAPIPaginationContext_8ba512fb
    from ask_smapi_model.v1.links import Links as Links_bc43467b
    from ask_smapi_model.v1.skill.interaction_model.jobs.job_definition_metadata import JobDefinitionMetadata as JobDefinitionMetadata_c4abc32a


class ListJobDefinitionsResponse(object):
    """
    The response of list job definitions.


    :param pagination_context: 
    :type pagination_context: (optional) ask_smapi_model.v1.skill.interaction_model.jobs.job_api_pagination_context.JobAPIPaginationContext
    :param links: 
    :type links: (optional) ask_smapi_model.v1.links.Links
    :param jobs: 
    :type jobs: (optional) list[ask_smapi_model.v1.skill.interaction_model.jobs.job_definition_metadata.JobDefinitionMetadata]

    """
    deserialized_types = {
        'pagination_context': 'ask_smapi_model.v1.skill.interaction_model.jobs.job_api_pagination_context.JobAPIPaginationContext',
        'links': 'ask_smapi_model.v1.links.Links',
        'jobs': 'list[ask_smapi_model.v1.skill.interaction_model.jobs.job_definition_metadata.JobDefinitionMetadata]'
    }  # type: Dict

    attribute_map = {
        'pagination_context': 'paginationContext',
        'links': '_links',
        'jobs': 'jobs'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, pagination_context=None, links=None, jobs=None):
        # type: (Optional[JobAPIPaginationContext_8ba512fb], Optional[Links_bc43467b], Optional[List[JobDefinitionMetadata_c4abc32a]]) -> None
        """The response of list job definitions.

        :param pagination_context: 
        :type pagination_context: (optional) ask_smapi_model.v1.skill.interaction_model.jobs.job_api_pagination_context.JobAPIPaginationContext
        :param links: 
        :type links: (optional) ask_smapi_model.v1.links.Links
        :param jobs: 
        :type jobs: (optional) list[ask_smapi_model.v1.skill.interaction_model.jobs.job_definition_metadata.JobDefinitionMetadata]
        """
        self.__discriminator_value = None  # type: str

        self.pagination_context = pagination_context
        self.links = links
        self.jobs = jobs

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, ListJobDefinitionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
